@@ -184,12 +184,12 @@ class ImpersonationView(View):
             return HttpResponseBadRequest('Token could not be validated. Error: {0}'.format(validate.error.message))
 
         # user and company checking
-        user_id = validate.user
+        username = validate.user
         company_id = validate.company
         auth_token = validate.auth_token
         
-        user = get_user_model().objects.filter(pk=user_id).first()
-        if not user: return HttpResponseBadRequest('User with ID {0} could not be found.'.format(user_id))
+        user = get_user_model().objects.filter(username=username).first()
+        if not user: return HttpResponseBadRequest('User with username {0} could not be found.'.format(username))
         company = CloudspotCompany.objects.filter(pk=company_id).first()
         if not company: return HttpResponseBadRequest('Company with ID {0} could not be found.'.format(company_id))
         if company not in user.available_companies.all(): return HttpResponseBadRequest('User is not in requested company.')
